@@ -1,35 +1,53 @@
+from __future__ import unicode_literals
+from inspect import getargspec
+from types import MethodType
+
 from java.util import EventListener
 
+_wrapperClassMap = {}  # event interface name -> wrapper class
 
-_wrapperClassMap = {}       # event interface name -> wrapper class
 
-def _createListenerWrapper(eventInterface, event, listener, args, kwargs,
+def _noOp(self, event):
+    pass
+
+
+def _createListenerWrapper(eventInterface, eventNames, listener, args, kwargs,
                            removeMethod):
-    events = (event,) if isinstance(event, basestring) else event
+    eventNames = ((eventNames,) if isinstance(eventNames, basestring) else
+                  sorted(eventNames))
     assert issubclass(eventInterface, EventListener), \
-        'event class must be a subclass of EventListener'
+        'eventName class must be a subclass of EventListener'
     assert hasattr(listener, '__call__'), 'listener must be callable'
-    for event in events:
-        assert hasattr(eventInterface, event), \
-            '%s has no method named "%s"' % (eventInterface.__name__, event)
+    for eventName in eventNames:
+        assert hasattr(eventInterface, eventName), \
+            '%s has no method named "%s"' % \
+            (eventInterface.__name__, eventName)
 
+    # Figure out the fully qualified name of the interface
     className = eventInterface.__name__
     if eventInterface.__module__:
         className = eventInterface.__module__ + '.' + className
+    mapKey = '%s/%s' % (className, ','.join(eventNames))
 
-    # Create a wrapper class for this event class if one doesn't exist already
-    if not className in _wrapperClassMap:
+    # Create a wrapper class for this eventName class if it's not there yet
+    wrapperClass = _wrapperClassMap.get(mapKey)
+    if not wrapperClass:
+        # Gather all the interface methods
+        methodNames = set()
+        for cls in eventInterface.__mro__:
+            if cls is EventListener:
+                break
+            methodNames.update(m for m in cls.__dict__ if
+                               not m.startswith('_'))
+
+        # Redirect all interface methods to self.handleEvent()
+        methods = {m: EventListenerWrapper.handleEvent
+                   if m in eventNames else _noOp for m in methodNames}
         wrapperClass = type('%sWrapper' % eventInterface.__name__,
-                            (EventListenerWrapper, eventInterface), {})
-        _wrapperClassMap[className] = wrapperClass
-    else:
-        wrapperClass = _wrapperClassMap[className]
+                            (EventListenerWrapper, eventInterface), methods)
+        _wrapperClassMap[mapKey] = wrapperClass
 
-    # Create a listener instance and add handleEvent as an instance method
-    wrapper = wrapperClass(listener, args, kwargs, removeMethod)
-    for event in events:
-        setattr(wrapper, event, wrapper.handleEvent)
-    return wrapper
+    return wrapperClass(listener, args, kwargs, removeMethod)
 
 
 class EventListenerWrapper(object):
@@ -47,8 +65,7 @@ class EventListenerWrapper(object):
         self.removeMethod(*self.removeMethodArgs)
 
 
-def addEventListener(target, eventInterface, event, listener,
-                             *args, **kwargs):
+def addEventListener(target, eventInterface, event, listener, *args, **kwargs):
     """
     Adds an event listener to `target`.
 
@@ -67,6 +84,12 @@ def addEventListener(target, eventInterface, event, listener,
              events (with :meth:`~EventListenerWrapper.unlisten`)
 
     """
+    # Sanity check
+    argspec = getargspec(listener)
+    min_args = 2 if isinstance(listener, MethodType) else 1
+    if len(argspec.args) < min_args and not argspec.varargs:
+        raise TypeError('The target callable has too few parameters declared')
+
     addMethodName = 'add%s' % eventInterface.__name__
     addMethod = getattr(target, addMethodName)
     removeMethodName = 'remove%s' % eventInterface.__name__
@@ -93,13 +116,15 @@ def addPropertyListener(target, property, listener, *args, **kwargs):
 
     """
     from java.beans import PropertyChangeListener
-    wrapper = _createListenerWrapper(PropertyChangeListener, 'propertyChange',
-        listener, args, kwargs, target.removePropertyChangeListener)
+    wrapper = _createListenerWrapper(
+        PropertyChangeListener, 'propertyChange', listener, args, kwargs,
+        target.removePropertyChangeListener)
     add_args = (wrapper,) if property is None else (property, wrapper)
     wrapper.removeMethodArgs = add_args
     target.addPropertyChangeListener(*add_args)
     return wrapper
 
+
 #
 # Shortcuts for java.awt.event
 #
@@ -147,6 +172,7 @@ def addMouseClickListener(target, listener, *args, **kwargs):
     return addEventListener(target, MouseListener, 'mouseClicked', listener,
                             *args, **kwargs)
 
+
 #
 # Shortcuts for javax.swing.events
 #
