@@ -2,20 +2,21 @@
 Contains convenience functions for working with formatters.
 
 """
+from __future__ import unicode_literals
 from decimal import Decimal
 
 from java.lang import Number, Long, Double
 from java.math import BigDecimal, BigInteger
 from java.text import DecimalFormat, DateFormat, NumberFormat, Format
-from javax.swing.text import DefaultFormatterFactory, InternationalFormatter, \
-    DateFormatter, NumberFormatter
-
+from javax.swing.text import (DefaultFormatterFactory, InternationalFormatter,
+                              DateFormatter, NumberFormatter)
 
 _TYPES_MAP = {int: Long,
               long: BigInteger,
               float: Double,
               Decimal: BigDecimal}
 
+
 class PyDecimalFormat(DecimalFormat):
     def __init__(self, pattern=None, integerDigits=None, fractionDigits=None,
                  **kwargs):
@@ -34,15 +35,7 @@ class PyDecimalFormat(DecimalFormat):
 
 class EmptyNumberFormatter(NumberFormatter):
     def stringToValue(self, text):
-        if not text:
-            return None
-
-        value = NumberFormatter.stringToValue(self, text)
-        if not isinstance(value, self.valueClass):
-            # Counteract Jython's automatic numeric type conversion
-            return self.valueClass(value)
-
-        return value
+        return NumberFormatter.stringToValue(self, text) if text else None
 
 
 def installFormat(field, format):
