@@ -6,7 +6,7 @@ from swingutils.beans import MirrorObject
 from swingutils.events import addListSelectionListener, addPropertyListener
 
 
-class DelegateTableModel(AbstractTableModel, AbstractDelegateList):
+class DelegateTableModel(AbstractDelegateList, AbstractTableModel):
     """
     Table model that wraps any list-like object, and fires events when its
     contents are manipulated (through the table model).
@@ -17,7 +17,7 @@ class DelegateTableModel(AbstractTableModel, AbstractDelegateList):
     (usually for the purpose of choosing an appropriate cell renderer).
     You can either override :attr:`__columns__` in a subclass, or supply it via
     the constructor.
-    
+
     List data is assumed to be a two-dimensional table (list of lists).
 
     """
@@ -33,8 +33,7 @@ class DelegateTableModel(AbstractTableModel, AbstractDelegateList):
         :param delegate: the list where this table model gets its data from
 
         """
-        AbstractTableModel.__init__(self)
-        AbstractDelegateList.__init__(self, delegate)
+        super(DelegateTableModel, self).__init__(delegate)
 
         self.__columns__ = list(args if args else self.__columns__)
         for index, column in enumerate(self.__columns__):
@@ -57,13 +56,16 @@ class DelegateTableModel(AbstractTableModel, AbstractDelegateList):
 
     def _fireItemsRemoved(self, start, end):
         self.fireTableRowsDeleted(start, end)
-    
-    def setDelegate(self, value):
+
+    @property
+    def delegate(self):
+        return self._delegate
+
+    @delegate.setter
+    def delegate(self, value):
         self._delegate = value
         self.fireTableDataChanged()
 
-    delegate = property(AbstractDelegateList.getDelegate, setDelegate)
-
     #
     # TableModel methods
     #
@@ -122,6 +124,7 @@ class ObjectTableModel(DelegateTableModel):
     #
 
     def __init__(self, delegate, *args):
+        # TODO: use super() when #1540 is fixed
         AbstractTableModel.__init__(self)
         AbstractDelegateList.__init__(self, delegate)
 
@@ -168,7 +171,7 @@ class ObjectTableModel(DelegateTableModel):
         for i, row in enumerate(self):
             if row == obj:
                 return i
-        return - 1
+        return -1
 
     def getSelectedObject(self, table):
         """
@@ -176,7 +179,6 @@ class ObjectTableModel(DelegateTableModel):
         multi-row selection enabled.
 
         """
-        assert table.model is self
         if table.selectedRow >= 0:
             modelRow = table.convertRowIndexToModel(table.selectedRow)
             return self[modelRow]
@@ -190,7 +192,6 @@ class ObjectTableModel(DelegateTableModel):
         :rtype: list
 
         """
-        assert table.model is self
         selected = []
         for viewRow in table.selectedRows:
             modelRow = table.convertRowIndexToModel(viewRow)
@@ -206,7 +207,6 @@ class ObjectTableModel(DelegateTableModel):
         :rtype: list
 
         """
-        assert table.model is self
         visible = []
         for viewRow in xrange(table.rowCount):
             modelRow = table.convertRowIndexToModel(viewRow)
